#region Using declarations
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Gui;
using NinjaTrader.Gui.Chart;
using NinjaTrader.Gui.SuperDom;
using NinjaTrader.Gui.Tools;
using NinjaTrader.Data;
using NinjaTrader.NinjaScript;
using NinjaTrader.Core.FloatingPoint;
using NinjaTrader.NinjaScript.DrawingTools;
#endregion

//This namespace holds Indicators in this folder and is required. Do not change it. 
namespace NinjaTrader.NinjaScript.Indicators
{
	public class LBROscillator : Indicator
	{
		 #region Variables
        // Wizard generated variables
            private int fast = 3; // Default setting for Fast
            private int slow = 10; // Default setting for Slow
            private int longLine = 16; // Default setting for LongLine
			private int MoMoPeriod = 40;  //Look for momentum highs
			private int BarHiLo = 20;  //Look for price highs
			private int BarLookback = 3;  //Period in which the BarHigh needs to have occurred   
			private Series<double>		diff;
			private Series<double>		avg;
			private SMA            smafast;
			private SMA            smaslow;
			private SMA            smalongline;
			private Brush dotcolor = Brushes.Lime;
		// User defined variables (add any user defined variables below)
        #endregion
		protected override void OnStateChange()
		{
			if (State == State.SetDefaults)
			{
				Description									= @"Enter the description for your new custom Indicator here.";
				Name										= "LBROscillator";
				Calculate									= Calculate.OnBarClose;
				IsOverlay									= false;
				DisplayInDataBox							= true;
				DrawOnPricePanel							= true;
				DrawHorizontalGridLines						= false;
				DrawVerticalGridLines						= false;
				PaintPriceMarkers							= true;
				ScaleJustification							= NinjaTrader.Gui.Chart.ScaleJustification.Right;
				//Disable this property if your indicator requires custom values that cumulate with each new market data event. 
				//See Help Guide for additional information.
				IsSuspendedWhileInactive					= true;
				
				AddPlot(new Stroke(Brushes.DarkOrange, 2), PlotStyle.Line, "OscLine");
	            AddPlot(new Stroke(Brushes.CornflowerBlue,2), PlotStyle.Bar, "OscBarUP");
				AddPlot(new Stroke(Brushes.Maroon,2), PlotStyle.Bar, "OscBarDn");
	            AddPlot(new Stroke(Brushes.Lime, 2), PlotStyle.Line, "HPLineUp");
				AddPlot(new Stroke(Brushes.DarkViolet,2), PlotStyle.Line, "HPLineDn");
				AddLine(Brushes.LightGray, 0, "ZeroLine");
			}
			else if (State == State.Configure)
			{
				diff				= new Series<double>(this);
				avg					= new Series<double>(this);
				smafast				= SMA(Input, fast);
				smaslow				= SMA(Input, slow);
				smalongline			= SMA(diff, longLine);
			}
		}

		protected override void OnBarUpdate()
		{
			 // Use this method for calculating your indicator values. Assign a value to each
            // plot below by replacing 'Close[0]' with your own formula.
			if( CurrentBar < longLine  || CurrentBar < slow  || CurrentBar < fast || CurrentBar < MoMoPeriod)
			{return;}
			
						
			diff[0] = (smafast[0] - smaslow[0]) / TickSize;
			
			avg[0] = smalongline[0];
			
			OscLinePlot[0] = (diff[0]);
			//Print(High + "     " + CurrentBar);
			if (IsRising(diff))
            	OscBarUpPlot[0] = (diff[0]);
			else
				OscBarDnPlot[0] = (diff[0]);
			
			if ((HighestBar(diff, MoMoPeriod) == 0 && HighestBar(High, BarHiLo) <= BarLookback) || (LowestBar(diff, MoMoPeriod) == 0 && LowestBar(Low, BarHiLo) <= BarLookback))
			{Draw.Dot(this,"Up Dot" + CurrentBar, true, 0, diff[0] , dotcolor,false);}
			
			if (IsRising(avg))
			{
				HPLinePlotUp[1] = avg[1];
				HPLinePlotUp[0] = avg[0] ;
			}
			else if (IsFalling(avg))
			{
				HPLinePlotDn[1] = avg[1];
				HPLinePlotDn[0] = avg[0] ;
			}
		}
		
		 #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Series<double> OscLinePlot
        {
            get { return Values[0]; }
        }

        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Series<double> OscBarUpPlot
        {
            get { return Values[1]; }
        }

		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Series<double> OscBarDnPlot
        {
            get { return Values[2]; }
        }
		
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Series<double> HPLinePlotUp
        {
            get { return Values[3]; }
        }

		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public Series<double> HPLinePlotDn
        {
            get { return Values[4]; }
        }
		
        [Description("Fast Avg")]
        [Category("Parameters")]
        public int Fast
        {
            get { return fast; }
            set { fast = Math.Max(1, value); }
        }

        [Description("Slow Avg")]
        [Category("Parameters")]
        public int Slow
        {
            get { return slow; }
            set { slow = Math.Max(1, value); }
        }

        [Description("HP Avg")]
        [Category("Parameters")]
        public int LongLine
        {
            get { return longLine; }
            set { longLine = Math.Max(1, value); }
        }
        #endregion
	}
}

#region NinjaScript generated code. Neither change nor remove.

namespace NinjaTrader.NinjaScript.Indicators
{
	public partial class Indicator : NinjaTrader.Gui.NinjaScript.IndicatorRenderBase
	{
		private LBROscillator[] cacheLBROscillator;
		public LBROscillator LBROscillator()
		{
			return LBROscillator(Input);
		}

		public LBROscillator LBROscillator(ISeries<double> input)
		{
			if (cacheLBROscillator != null)
				for (int idx = 0; idx < cacheLBROscillator.Length; idx++)
					if (cacheLBROscillator[idx] != null &&  cacheLBROscillator[idx].EqualsInput(input))
						return cacheLBROscillator[idx];
			return CacheIndicator<LBROscillator>(new LBROscillator(), input, ref cacheLBROscillator);
		}
	}
}

namespace NinjaTrader.NinjaScript.MarketAnalyzerColumns
{
	public partial class MarketAnalyzerColumn : MarketAnalyzerColumnBase
	{
		public Indicators.LBROscillator LBROscillator()
		{
			return indicator.LBROscillator(Input);
		}

		public Indicators.LBROscillator LBROscillator(ISeries<double> input )
		{
			return indicator.LBROscillator(input);
		}
	}
}

namespace NinjaTrader.NinjaScript.Strategies
{
	public partial class Strategy : NinjaTrader.Gui.NinjaScript.StrategyRenderBase
	{
		public Indicators.LBROscillator LBROscillator()
		{
			return indicator.LBROscillator(Input);
		}

		public Indicators.LBROscillator LBROscillator(ISeries<double> input )
		{
			return indicator.LBROscillator(input);
		}
	}
}

#endregion
